(function() {
    // xg2.js
    
    let margin = {top: 20, right: 30, bottom: 50, left: 150}; // Ajustamos los márgenes para espacio en el eje Y
    let width = 800 - margin.left - margin.right;
    let height = 370 - margin.top - margin.bottom;
    
    let x = d3.scaleLinear().range([0, width]);
    let y = d3.scaleBand().range([0, height]).padding(0.1);
    let color = d3.scaleOrdinal(d3.schemeCategory10);
    

    // Contenedor para la leyenda
    let legendContainer = d3.select("#tab2")
        .append("div")
        .attr("id", "legendContainer")
        .style("position", "absolute")
        .style("top", "160px")
        .style("left", "850px")
        .style("width", "80px")
        .style("height", "300px")
        .style("border", "2px solid black")
        .style("padding", "10px")
        .style("background-color", "#f0f0f0");

    legendContainer.html(`
        <h3>Leyenda</h3>
        <p><span style="color: blue;">──</span> Goles>xG</p>
        <p><span style="color: red;">──</span> xG>Goles</p>
    `);

    // Contenedor SVG
    let svgContainer = d3.select("#tab2"); // Contenedor específico para la pestaña
    let svg;
    
    let data; // Variable global para los datos

    window.infoContainer2 = d3.select("body")
    .append("div")
    .attr("id", "infoContainer")
    .style("position", "absolute")
    .style("top", 160 + "px")
    .style("left", (width + margin.left + margin.right + 160) + "px")
    .style("width", "260px")
    .style("height", "390px")
    .style("border", "4px solid black")
    .style("padding", "10px")
    .style("background-color", "#f9f9f9")
    .style("display", "block") // Siempre visible
    .html(`<h1>Haz clic en una barra para ver detalles.</h1>`); // Mensaje predeterminado
    
    // Cargar datos desde el CSV
    d3.csv("./understat.com.csv").then(function(loadedData) {
        console.log("Datos cargados:", loadedData); // Depuración: verificar datos cargados
        data = loadedData.map(d => {
            d.scored = +d.scored;
            d.xG = +d.xG;
            d.xG_diff = +d.xG_diff; // Asegurarnos de que xG_diff sea numérico
            d.xG_diff = +d.xG_diff; // Asegurarnos de que xG_diff sea numérico
            d.xpts = +d.xpts;
            return d;
        });
    
        console.log("Datos procesados:", data); // Depuración: verificar datos procesados
    
        // Inicializar con valores por defecto
        updateGraph2(2014, "La_liga");
    
        // Evento para cambiar el gráfico cuando se selecciona un año
        d3.select("#yearSelector2").on("change", function() {
            let selectedYear = +this.value;
            let selectedTrophie = d3.select("#trophieSelector2").node().value;
            updateGraph2(selectedYear, selectedTrophie);
        });
    
        // Evento para cambiar el gráfico cuando se selecciona una liga
        d3.select("#trophieSelector2").on("change", function() {
            let selectedYear = +d3.select("#yearSelector2").node().value;
            let selectedTrophie = this.value;
            updateGraph2(selectedYear, selectedTrophie);
        });
    
    }).catch(function(error) {
        console.error("Error al cargar el archivo CSV:", error);
    });
    
    function updateGraph2(year, trophie) {
        console.log(`Actualizar gráfico: Año=${year}, Liga=${trophie}`); // Depuración: parámetros seleccionados
    
        // Filtrar los datos según el año y la liga seleccionados
        let filteredData = data.filter(d => +d.Year === year && d.Trophie === trophie);
    
        console.log("Datos filtrados:", filteredData); // Depuración: verificar datos filtrados
    
        if (filteredData.length === 0) {
            console.warn("No se encontraron datos para los filtros seleccionados.");
        }
    
        // Ordenar los datos por la columna scored de mayor a menor
        filteredData.sort((a, b) => b.xG_diff - a.xG_diff);

        // Eliminar el SVG existente si ya está presente
        svgContainer.select("svg").remove(); // Asegura que sólo exista un gráfico por pestaña

        // Crear un nuevo título
        svgContainer.select("h2").remove(); // Eliminar título anterior si existe
        svgContainer.append("h2")
            .text(`Diferencia xG-Goles anotados: ${trophie} ${year}-${year + 1}`)
            .style("text-align", "center-left")
            .style("margin-bottom", "10px");
    
        // Crear un nuevo SVG
        svg = svgContainer
            .append("svg")
            .attr("width", width + margin.left + margin.right)
            .attr("height", height + margin.top + margin.bottom)
          .append("g")
            .attr("transform", "translate(" + margin.left + "," + margin.top + ")");
    
        // Configurar el dominio de la escala X para que tenga 0 en el centro
        x.domain([
            d3.min(filteredData, d => d.xG_diff), // Valor mínimo de xG_diff
            d3.max(filteredData, d => d.xG_diff)  // Valor máximo de xG_diff
        ]).nice(); // .nice() ajusta el dominio para que esté en números redondos
    
        y.domain(filteredData.map(d => d.team)); // Configurar dominio del eje Y
    
        // Dibujar ejes
        svg.append("g")
            .attr("transform", `translate(0,${height})`)
            .call(d3.axisBottom(x).ticks(5)); // Eje X con valores de xG_diff
    
        svg.append("g")
            .call(d3.axisLeft(y));
    
        // Añadir el texto sobre el fondo
        svg.append("text")
            .attr("x", width / 2)
            .attr("y", height + 40)
            .attr("text-anchor", "middle")
            .attr("font-weight", "bold") // Texto en negrita
            .attr("font-size", "24px") // Tamaño mayor
            .attr("fill", "black") // Color del texto (negro)
            .text("Diferencia de xG (xG_diff)");
    
        // Añadir el texto sobre el fondo
        svg.append("text")
            .attr("transform", "rotate(-90)") // Rota el texto
            .attr("x", -height / 2)
            .attr("y", -120)
            .attr("text-anchor", "middle")
            .attr("font-weight", "bold") // Aplica la negrita
            .attr("font-size", "24px") // Ajusta el tamaño del texto
            .attr("fill", "black") // Color del texto (negro)
            .text("Equipo");
    
       // Dibujar las barras horizontales basadas en xG_diff
        svg.selectAll(".bar")
            .data(filteredData)
            .enter()
            .append("rect")
            .attr("class", "bar")
            .attr("x", d => Math.min(x(0), x(d.xG_diff))) // Ajustar para valores positivos y negativos
            .attr("y", d => y(d.team))
            .attr("width", d => Math.abs(x(d.xG_diff) - x(0))) // Longitud proporcional a xG_diff
            .attr("height", y.bandwidth())
            .attr("fill", d => {
                const intensity = Math.min(10, Math.abs(d.xG_diff) / 10); // Escala de intensidad ajustable
                return d.xG_diff > 0 
                    ? d3.interpolateBlues(intensity) // Azul para valores positivos
                    : d3.interpolateReds(intensity); // Rojo para valores negativos
            })
            .on("click", function(event, d) {
                infoContainer2
                    .style("display", "block")
                    .html(`
                        <h1>${d.team}</h1>
                        <p><strong>Posición en liga:</strong> ${d.position}</p>
                        <p><strong>Partidos jugados:</strong> ${d.matches}</p>
                        <p><strong>Victorias/empates/derrotas:</strong> ${d.wins}/${d.draws}/${d.loses}</p>
                        <p><strong>Goles:</strong> ${d.scored}</p>
                        <p><strong>xG:</strong> ${d.xG.toFixed(2)}</p>
                        <p><strong>Diferencia Goles-xG:</strong> ${d.xG_diff.toFixed(2)}</p>
                        <p><strong>Puntos:</strong> ${d.pts}</p>
                        <p><strong>Puntos esperados:</strong> ${d.xpts.toFixed(2)}</p>
                    `);
            });

    }
    
    })();
    